package utils

import (
	"fmt"

	beeLogger "github.com/beego/bee/v2/logger"
	"github.com/beego/beego/v2/server/web"
)

// 数据库配置
var (
	RunMode          string // 运行模式
	MYSQL_URL_MASTER string // 数据库地址
	MYSQL_URL_RDDP   string // 数据库地址

	REDIS_CACHE string      //缓存地址
	Rc          RedisClient //redis缓存
)

// 阿里云配置
var (
	Bucketname       string
	Endpoint         string
	Imghost          string
	UploadDir        string
	Upload_Audio_Dir string
	AccessKeyId      string
	AccessKeySecret  string
)

// 阿里云oss前端上传用
var (
	AliStsScheme       string
	RegionId           string
	RoleArn            string
	RoleSessionName    string
	RAMAccessKeyId     string
	RAMAccessKeySecret string
	STSTokenCacheKey   string
)

// 基础配置
var (
	STATIC_DIR string
)

var (
	LogPath    string //调用过程中的日志存放地址
	LogFile    string
	ApiLogPath string // 接口请求地址和接口返回值日志存放地址
	ApiLogFile string
	BinLogPath string // 数据库相关的日志存放地址
	BinLogFile string
	LogMaxDays int // 日志最大保留天数
)

var DesKey string // 接口返回加密KEY

func init() {
	tmpRunMode, err := web.AppConfig.String("run_mode")
	if err != nil {
		panic(any("配置文件读取run_mode错误 " + err.Error()))
	}
	RunMode = tmpRunMode
	fmt.Println("RunMode:", RunMode)
	if RunMode == "" {
		configPath := `/home/code/config/eta_mini_crm/conf/app.conf`
		fmt.Println("configPath:", configPath)
		err = web.LoadAppConfig("ini", configPath)
		if err != nil {
			fmt.Println("web.LoadAppConfig Err:" + err.Error())
		}
		tmpRunMode, _ := web.AppConfig.String("run_mode")
		RunMode = tmpRunMode
	}

	config, err := web.AppConfig.GetSection(RunMode)
	if err != nil {
		panic(any("配置文件读取错误 " + err.Error()))
	}
	beeLogger.Log.Info(RunMode + " 模式")
	MYSQL_URL_RDDP = config["mysql_url_rddp"]
	MYSQL_URL_MASTER = config["mysql_url_master"]

	REDIS_CACHE = config["beego_cache"]
	if len(REDIS_CACHE) <= 0 {
		panic(any("redis链接参数没有配置"))
	}
	// 接口返回加密KEY
	DesKey = config["des_key"]

	// OSS相关
	{
		Endpoint = config["endpoint"]
		Bucketname = config["bucket_name"]
		Imghost = config["img_host"]
		UploadDir = config["upload_dir"]
		Upload_Audio_Dir = config["upload_audio_dir"]
		AccessKeyId = config["access_key_id"]
		AccessKeySecret = config["access_key_secret"]
	}

	// OSS相关（前端使用）
	{
		AliStsScheme = config["ali_sts_scheme"]
		RegionId = config["region_id"]
		RoleArn = config["role_arn"]
		RoleSessionName = config["role_session_name"]
		RAMAccessKeyId = config["ram_access_key_id"]
		RAMAccessKeySecret = config["ram_access_key_secret"]
		STSTokenCacheKey = config["sts_token_cache_key"]
	}

	// 静态文件目录
	STATIC_DIR = config["static_dir"]
	if STATIC_DIR == "" {
		STATIC_DIR = "./static"
	}

	// 初始化缓存
	redisClient, err := initRedis(config["redis_type"], config["beego_cache"])
	if err != nil {
		fmt.Println("redis链接异常：", err)
		panic(any("redis链接参数没有配置"))
	}

	Rc = redisClient

}
